@@ -902,6 +902,9 @@ class Tasks(Endpoint):
         target_options_merge: bool = False,
         target_timeout: Optional[int] = None,
         target_workers: Optional[int] = None,
+        target_assembly: Optional[str] = None,
+        target_class: Optional[str] = None,
+        target_method: Optional[str] = None,
         vm_count: int = 1,
         preserve_existing_outputs: bool = False,
         colocate: bool = False,
@@ -975,6 +978,9 @@ class Tasks(Endpoint):
                 target_options_merge=target_options_merge,
                 target_timeout=target_timeout,
                 target_workers=target_workers,
+                target_assembly=target_assembly,
+                target_class=target_class,
+                target_method=target_method,
                 type=task_type,
                 wait_for_files=task_wait_for_files,
                 report_list=report_list,
